View

Struct View 

pub struct View {
    pub view_id: Option<usize>,
    /* private fields */
}
A group of DrawCalls.

This is really a pointer to a CxView (indexed in Cx::views using View::view_id), so you can find more information there.

A View has a few special features:

  • It has its own Rect, within which everything is clipped (see also [DrawUniforms]). This typically gets set by the return value of Cx::end_typed_box for the [CxLayoutBox] that is associated with the View. TODO(JP): Look into decoupling [CxLayoutBox] from View.
  • It can scroll (but does not have to; again see also [DrawUniforms]).
  • It has its own set of DrawCalls, which are isolated from the DrawCalls of the parent View.

See also ViewArea, which is an Area pointer to a View.

Fields

view_id: Option<usize>

The index of the corresponding CxView in Cx::views.

Implementations

Source

impl View

pub fn with_is_overlay(self, is_overlay: bool) -> Self

Creates a new, empty View. See View::is_overlay.

pub fn begin_view(&mut self, cx: &mut Cx, layout_size: LayoutSize)

Register the View in the draw tree.

This also creates a new [CxLayoutBox] with the LayoutSize that is passed in. Note that you should not create a View just in order to get a new [CxLayoutBox], since creating a View is relatively expensive โ€“ no DrawCalls inside this View will get merged with ones outside of it, so adding too many Views will create too many individual calls to the GPU.

TODO(JP): Perhaps we should decouple [CxLayoutBox] and View altogether?

pub fn end_view(&mut self, cx: &mut Cx) -> Area

End the View, by ending the [CxLayoutBox]. Returns a ViewArea that you can hold onto.

Should only be called if View::begin_view returned Result::Ok.

TODO(JP): Is the ViewArea redundant, since it basically contains the same information as the View itself?

pub fn get_rect(&self, cx: &Cx) -> Rect

Get the Rect that the [CxLayoutBox] associated with the View returned.

TODO(JP): Should we return an Option<Rect> instead of just returning a zero-sized Rect when the View has never been drawn yet?

TODO(JP): Doesnโ€™t check if the View::redraw_id is still up to date, so we might be returning an outdated Rect here.

pub fn area(&self) -> Area

Returns an Area::View for this View, or Area::Empty if the View hasnโ€™t been instantiated yet.

pub fn get_scroll_pos(&self, cx: &Cx) -> Vec2

Get the current CxView::unsnapped_scroll if the View has been instantiated.